ESH

Executive Shell
git clone http://git.omkov.net/ESH
Log | Tree | Refs | README | Download

AuthorJamozed <[email protected]>
Date2021-08-07 11:43:12
Commit72dbdd3d35425c534962c59517f8edca929bf1d1
Parentfa654935873a420e551da1c5d6319aa29f66066e

Rename OSH to ESH

Diffstat

M CHANGELOG | 5 ++++-
M CMakeLists.txt | 6 +++---
M README.md | 8 ++++----
M src/alias.c | 2 +-
M src/alias.h | 8 ++++----
M src/bltn.c | 4 ++--
M src/bltn.h | 8 ++++----
M src/bltns/cd.c | 4 ++--
M src/bltns/pwd.c | 2 +-
M src/exec.c | 2 +-
M src/exec.h | 8 ++++----
M src/lineread.c | 2 +-
M src/lineread.h | 8 ++++----
M src/main.c | 2 +-
M src/parse.c | 2 +-
M src/parse.h | 8 ++++----

16 files changed, 41 insertions, 38 deletions

diff --git a/CHANGELOG b/CHANGELOG
index 22c70f8..68cda6c 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,3 +1,6 @@
+0.5.0, 
+* Rename OSH to ESH
+
 0.4.0, 2021-04-01
 * Fix SIGINT handling at prompt
 * Ensure terminal state is restored on exit
@@ -22,7 +25,7 @@
 * Add PWD builtin
 * Move to token based parsing
 * Add rudimentary support for multi-line commands
-* Rebrand to OSH, OMKOV Shell
+* Rebrand to ESH, OMKOV Shell
 
 0.1.0, 2020-01-31
 * Implement basic shell loop
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 5d38543..3b2ffb3 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -1,11 +1,11 @@
 CMAKE_MINIMUM_REQUIRED(VERSION 3.12)
-PROJECT(OSH VERSION 0.4.0 LANGUAGES C)
+PROJECT(ESH VERSION 0.5.0 LANGUAGES C)
 
 SET(CMAKE_RUNTIME_OUTPUT_DIRECTORY ${PROJECT_SOURCE_DIR}/bin)
 ADD_COMPILE_DEFINITIONS(PROJECT_VERSION="${PROJECT_VERSION}")
 
-FILE(GLOB LIBSRC ${CMAKE_SOURCE_DIR}/src/lib/*)
 FILE(GLOB SOURCES ${CMAKE_SOURCE_DIR}/src/*)
+FILE(GLOB LIBSRC ${CMAKE_SOURCE_DIR}/src/lib/*)
 FILE(GLOB BLTNSRC ${CMAKE_SOURCE_DIR}/src/bltns/*)
 
-ADD_EXECUTABLE(osh ${SOURCES} ${LIBSRC} ${BLTNSRC})
+ADD_EXECUTABLE(esh ${SOURCES} ${LIBSRC} ${BLTNSRC})
diff --git a/README.md b/README.md
index b32a757..1b67a7b 100644
--- a/README.md
+++ b/README.md
@@ -1,12 +1,12 @@
-# OSH
+# ESH
 
-> OMKOV Shell
+> Executive Shell
 
-OSH is a modern shell with an emphasis on performance.
+ESH is a modern shell with an emphasis on performance.
 
 ## Build Instructions
 
-OSH uses CMake to build.  
+ESH uses CMake to build.  
 Binaries will be located in the `bin` directory.
 
 ### UNIX Build
diff --git a/src/alias.c b/src/alias.c
index b226a94..ffddd28 100644
--- a/src/alias.c
+++ b/src/alias.c
@@ -1,5 +1,5 @@
 // alias.c
-// Alias source file for OSH
+// Alias source file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
diff --git a/src/alias.h b/src/alias.h
index a44041e..9e5a8a6 100644
--- a/src/alias.h
+++ b/src/alias.h
@@ -1,5 +1,5 @@
 // alias.h
-// Alias header file for OSH
+// Alias header file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
@@ -30,8 +30,8 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 */
 
-#ifndef OSH_ALIAS_H_0BXOPDLM
-#define OSH_ALIAS_H_0BXOPDLM
+#ifndef ESH_ALIAS_H_0BXOPDLM
+#define ESH_ALIAS_H_0BXOPDLM
 
 #include <stddef.h>
 
@@ -45,4 +45,4 @@ extern void pushalias(akas_t *akas, aka_t aka);
 
 extern int bltn_alias(char *argv[]);
 
-#endif // OSH_ALIAS_H_0BXOPDLM
+#endif // ESH_ALIAS_H_0BXOPDLM
diff --git a/src/bltn.h b/src/bltn.h
index 5c78394..3c461ca 100644
--- a/src/bltn.h
+++ b/src/bltn.h
@@ -1,5 +1,5 @@
 // bltn.h
-// Builtin header file for OSH
+// Builtin header file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
@@ -30,10 +30,10 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 */
 
-#ifndef OMKOV_OSH_BLTN_H_XQ5D812A
-#define OMKOV_OSH_BLTN_H_XQ5D812A
+#ifndef OMKOV_ESH_BLTN_H_XQ5D812A
+#define OMKOV_ESH_BLTN_H_XQ5D812A
 
 struct bltn { const char *s; int (*f)(char *[]); };
 extern struct bltn bltns[];
 
-#endif // OMKOV_OSH_BLTN_H_XQ5D812A
+#endif // OMKOV_ESH_BLTN_H_XQ5D812A
diff --git a/src/bltns/pwd.c b/src/bltns/pwd.c
index ba48713..d77cf09 100644
--- a/src/bltns/pwd.c
+++ b/src/bltns/pwd.c
@@ -1,5 +1,5 @@
 // pwd.c, version 1.0.1b
-// OMKOV coreutils pwd adapted as an OSH builtin
+// OMKOV coreutils pwd adapted as an ESH builtin
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
diff --git a/src/exec.c b/src/exec.c
index 0ddea20..8364840 100644
--- a/src/exec.c
+++ b/src/exec.c
@@ -1,5 +1,5 @@
 // exec.c
-// Exec source file for OSH
+// Exec source file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
diff --git a/src/exec.h b/src/exec.h
index e11043e..7bc9cfb 100644
--- a/src/exec.h
+++ b/src/exec.h
@@ -1,5 +1,5 @@
 // exec.h
-// Exec header file for OSH
+// Exec header file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
@@ -30,11 +30,11 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 */
 
-#ifndef OMKOV_OSH_EXEC_H_VI5E8LVV
-#define OMKOV_OSH_EXEC_H_VI5E8LVV
+#ifndef OMKOV_ESH_EXEC_H_VI5E8LVV
+#define OMKOV_ESH_EXEC_H_VI5E8LVV
 
 extern int _loop, _ret;
 
 extern int execute(char *argv[]);
 
-#endif // OMKOV_OSH_EXEC_H_VI5E8LVV
+#endif // OMKOV_ESH_EXEC_H_VI5E8LVV
diff --git a/src/lineread.c b/src/lineread.c
index 27357f1..24c6022 100644
--- a/src/lineread.c
+++ b/src/lineread.c
@@ -1,5 +1,5 @@
 // lineread.c
-// Lineread source file for OSH
+// Lineread source file for ESH
 // Copyright (C) 2021, Jakob Wakeling
 // All rights reserved.
 
diff --git a/src/lineread.h b/src/lineread.h
index 3549af1..cc5fa15 100644
--- a/src/lineread.h
+++ b/src/lineread.h
@@ -1,5 +1,5 @@
 // lineread.h
-// Lineread header file for OSH
+// Lineread header file for ESH
 // Copyright (C) 2021, Jakob Wakeling
 // All rights reserved.
 
@@ -30,9 +30,9 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 */
 
-#ifndef OMKOV_OSH_LINEREAD_H_RPVXY3N7
-#define OMKOV_OSH_LINEREAD_H_RPVXY3N7
+#ifndef OMKOV_ESH_LINEREAD_H_RPVXY3N7
+#define OMKOV_ESH_LINEREAD_H_RPVXY3N7
 
 extern char *lineread(void);
 
-#endif // OMKOV_OSH_LINEREAD_H_RPVXY3N7
+#endif // OMKOV_ESH_LINEREAD_H_RPVXY3N7
diff --git a/src/main.c b/src/main.c
index 7f17086..84a0f12 100644
--- a/src/main.c
+++ b/src/main.c
@@ -1,5 +1,5 @@
 // main.c
-// Main source file for OSH
+// Main source file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
diff --git a/src/parse.c b/src/parse.c
index b357220..1c9b7f6 100644
--- a/src/parse.c
+++ b/src/parse.c
@@ -1,5 +1,5 @@
 // parse.c
-// Parser source file for OSH
+// Parser source file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
diff --git a/src/parse.h b/src/parse.h
index fa26606..d855040 100644
--- a/src/parse.h
+++ b/src/parse.h
@@ -1,5 +1,5 @@
 // parse.h
-// Parser header file for OSH
+// Parser header file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
@@ -30,9 +30,9 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 */
 
-#ifndef OMKOV_OSH_PARSE_H_G9TJ04KR
-#define OMKOV_OSH_PARSE_H_G9TJ04KR
+#ifndef OMKOV_ESH_PARSE_H_G9TJ04KR
+#define OMKOV_ESH_PARSE_H_G9TJ04KR
 
 extern char **parse(char *s, char **e);
 
-#endif // OMKOV_OSH_PARSE_H_G9TJ04KR
+#endif // OMKOV_ESH_PARSE_H_G9TJ04KR
diff --git a/src/bltn.c b/src/bltn.c
index 4d4f2e4..130b76e 100644
--- a/src/bltn.c
+++ b/src/bltn.c
@@ -1,5 +1,5 @@
 // bltn.c
 // Builtin source file for OSH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
@@ -64,5 +64,5 @@ struct bltn bltns[] = {
 };
 
 static int bltn_help(char *av[]) { (void)(av);
-	puts("OSH, version " PROJECT_VERSION); return 0;
+	puts("ESH, version " PROJECT_VERSION); return 0;
 }
@@ -1,5 +1,5 @@
 // bltn.c
-// Builtin source file for OSH
+// Builtin source file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
diff --git a/src/bltns/cd.c b/src/bltns/cd.c
index 1b84444..60c2140 100644
--- a/src/bltns/cd.c
+++ b/src/bltns/cd.c
@@ -1,5 +1,5 @@
 // cd.c, version 0.1.1
 // cd builtin source file for OSH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.
 
@@ -85,7 +85,7 @@ static void hlp(void) {
 }
 
 static void ver(void) {
-	puts("OSH cd, version " VERSION);
+	puts("ESH cd, version " VERSION);
 	puts("Copyright (C) 2020, Jakob Wakeling");
 	puts("All rights reserved.");
 	puts("OMKOV Permissive Licence (https://www.omkov.net/OLPE)");
@@ -1,5 +1,5 @@
 // cd.c, version 0.1.1
-// cd builtin source file for OSH
+// cd builtin source file for ESH
 // Copyright (C) 2020, Jakob Wakeling
 // All rights reserved.